import java.util.*;
import java.io.*;

public class TestsGenerator {
	
	final static int MAXK = 100;

	Random rand = new Random(366239);

	class Pair {
		long a;
		long b;

		public Pair(long a, long b) {
			this.a = a;
			this.b = b;
		}

	}

	class Phase {
		long a0, b0;
		long a, b;

		public Phase(long a0, long b0, long a, long b) {
			this.a0 = a0;
			this.b0 = b0;
			this.a = a;
			this.b = b;
		}

		long nextLong(long x) {
			if (x == 0) return 0;
			else return Math.abs(rand.nextLong()) % x;
		} 

		public Pair getAB() {
	    	long cnt = (a - a0) / b0;
	    	return new Pair(a + (nextLong(cnt)) * b0 , b);
		}

	}

	class InputDataFactory {
		private final Random r;

		public InputDataFactory() {
			r = new Random(566);	
		}

		InputData simpleNo() {
			return new InputData(1 + r.nextInt(1000000), 1 + r.nextInt(1000000), 
					             1 + r.nextInt(1000000), 1 + r.nextInt(1000000));
		}

		InputData simpleYes() {
			ArrayList<Pair> list = new ArrayList<Pair>();
			long a = 1 + r.nextInt(1000000);
			long b = 1 + r.nextInt(1000000);
			long aa = a;
			long bb = b;
			while (true) {
				if (b == 0) {
					break;
				}
				list.add(new Pair(a, b));
				if (a < b) {
					long t = a;
					a = b;
					b = t;
					continue;
				}
                a = a - b;				
			}
			int index = -1;
			while (true) {
				index = r.nextInt(list.size());
				if (list.get(index).b != 0 && list.get(index).a != 0) {
					break;
				}
			}
			long c = list.get(index).a;
			long d = list.get(index).b;
			return new InputData(aa, bb, c, d);
		} 

		public InputData simple() {
			if (r.nextBoolean()) {
				return simpleYes();	
			} else {
				return simpleNo();	
			}
		}

		ArrayList<Phase> pl; 
    
		InputData difficultYes() {
			long a = 1 + nextLong();
			long b = 2 + r.nextInt(100);
//			long b = 1 + nextLong();
			long aa = a;
			long bb = b;
			pl = new ArrayList<Phase>();
			euclid(a, b);
			int index = -1;
			int itCount = 0;
			while (true) {
				itCount++;
				if (itCount > 100) {
					return difficultYes();
				}
				index = r.nextInt(pl.size());
				if (pl.get(index).b != 0) {
					break;
				}
			}
			Pair res = pl.get(index).getAB();

			return new InputData(aa, bb, res.a, res.b);
		}
		 
    	public long euclid(long a, long b) {
//    		System.out.println(a + " " + b);
    		if (a < b) {
    			pl.add(new Phase(a, b, b, a));
    			long t = a;
    			a = b;
    			b = t;
	    	}
    		if (b == 0) return a;
    		pl.add(new Phase(a, b, b, a % b));
	    	return euclid(b, a % b);
    	}

		public InputData difficult() {
			if (r.nextBoolean()) {
				return difficultYes();	
			} else {
				return difficultNo();	
			}
		}

//		InputData difficultNo() {
//			return new InputData(1 + nextLong(), 1 + nextLong(), 
//					             1 + nextLong(), 1 + nextLong());
//		}

		InputData difficultNo() {
			return new InputData(1 + nextLong(), 1 + r.nextInt(1000), 
					             1 + nextLong(), 1 + nextLong());
		}

		long nextLong() {
			return Math.abs(r.nextLong()) % 1000000000000000000l;
		}
		
	}

	class TestFactory {
		Random r = new Random(239);
		InputDataFactory idf = new InputDataFactory();

		Test simpleTest() {
			Test res = new Test();
			int k = 1 + r.nextInt(MAXK);
			for (int i = 0; i < k; i++) {
				res.list.add(idf.simple());	
			}
			return res;
		}

		Test difficultTest() {
			Test res = new Test();
			int k = 1 + r.nextInt(MAXK);
			for (int i = 0; i < k; i++) {
				res.list.add(idf.difficult());	
			}
			return res;
		}

		Test maxKTest() {
			Test res = new Test();
			int k = MAXK;
			for (int i = 0; i < k; i++) {
				res.list.add(idf.difficult());	
			}
			return res;
		}

	}

	class InputData {
		long a, b, c, d;

		public InputData(long a, long b, long c, long d) {
			this.a = a;
			this.b = b;
			this.c = c;
			this.d = d;
		}

		public void print(PrintWriter out) {
			out.println(a + " " + b);
			out.println(c + " " + d);
		}

	}

	class Test {
		
		ArrayList<InputData> list = new ArrayList<InputData>();

		public Test() {
		}

    	void writeTest() throws IOException {
    		String fname = (curTest / 10) + "" + (curTest % 10);
    		curTest++;
    		PrintWriter out = new PrintWriter(new File(fname));

    		out.println(list.size());
    		for (InputData id : list) {
    			id.print(out);
    		}

    		out.close();
    	}
    }

    int curTest;

    public TestsGenerator(int firstTest) {
    	curTest = firstTest;

    }

    void genTests() throws IOException {
//        throw new RuntimeException("Not implemented :)");
    	TestFactory tf = new TestFactory();
    	for (int i = 0; i < 3; i++) {
    		(tf.simpleTest()).writeTest();
    	}
    	for (int i = 0; i < 6; i++) {
    		(tf.difficultTest()).writeTest();
    	}
   		(tf.maxKTest()).writeTest();
	}

    public static void main(String[] args) throws IOException {
    	int firstTest = Integer.parseInt(args[0]);
    	(new TestsGenerator(firstTest)).genTests();
    }

}